-- LuaRocks configuration

rocks_trees = {
   { name = "user", root = home .. "/.luarocks" };
   { name = "system", root = "/usr/local" };
}
lua_interpreter = "lua54";
variables = {
   LUA_DIR = "/usr/local";
   LUA_INCDIR = "/usr/local/include/lua-5.4";
   LUA_BINDIR = "/usr/local/bin";
   LUA_LIBDIR = "/usr/local/lib";
}
